# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from wxPython.wx import *

ID_ABOUT = 101
ID_EXIT  = 102
REMOVE_COLUMNS = 103
ADD_COLUMNS = 104

class ColumnList(wxListBox):
    def __init__(self, parent, items):
        wxListBox.__init__(self, parent, -1, size = (220, 220), style=wxLB_EXTENDED)
        self.InsertItems(items, 0)

class ColumnDialog(wxDialog):
    def __init__(self, enabledstrings, disabledstrings):
        wxDialog.__init__(self, NULL, -1, _("Columneditor"), size = wxSize(600, 300),
                          style = wxRESIZE_BORDER | wxCAPTION | wxSYSTEM_MENU)
        main_sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        disabledstrings.sort()
        self.removedcolumns = ColumnList(self, disabledstrings)
        hsizer.Add(self.removedcolumns, 1, wxEXPAND | wxALL, 5)

        tsizer = wxBoxSizer(wxVERTICAL)
        tsizer.Add(wxButton(self, REMOVE_COLUMNS, "<<"), 0, wxALIGN_CENTRE | wxALL, 5)
        tsizer.Add(wxButton(self, ADD_COLUMNS, ">>"), 0, wxALIGN_CENTRE | wxALL, 5)
        hsizer.Add(tsizer, 0, wxALIGN_CENTRE | wxALL, 5)

        self.addcolumns = ColumnList(self, enabledstrings)
        hsizer.Add(self.addcolumns, 1, wxEXPAND | wxALL, 5)

        main_sizer.Add(hsizer, 1, wxEXPAND | wxALL, 5)

        line = wxStaticLine(self, -1, style = wxLI_HORIZONTAL)
        main_sizer.Add(line, 0, wxEXPAND | wxALIGN_CENTRE, 5)

        hsizer = wxBoxSizer(wxHORIZONTAL)
        button = wxButton(self, wxID_OK, _("Ok"))
        button.SetDefault()
        hsizer.Add(button, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)
        hsizer.Add(wxButton(self, wxID_CANCEL, _("Cancel")),
                   0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)
        main_sizer.Add(hsizer, 0, wxALIGN_RIGHT | wxALL, 5)

        self.SetSizer(main_sizer)
        self.SetAutoLayout(True)
        main_sizer.Fit(self)

        EVT_BUTTON(self, REMOVE_COLUMNS, self.OnRemoveColumns)
        EVT_BUTTON(self, ADD_COLUMNS, self.OnAddColumns)

    def OnRemoveColumns(self, event):
        self.MoveColumns(self.addcolumns, self.removedcolumns)

    def OnAddColumns(self, event):
        self.MoveColumns(self.removedcolumns, self.addcolumns)

    def MoveColumns(self, srccolumns, dstcolumns):
        self.mytuple = srccolumns.GetSelections()
        y = 0
        for x in range(len(self.mytuple)):
            dstcolumns.Append(srccolumns.GetString(self.mytuple[x] - y))
            srccolumns.Delete(self.mytuple[x] - y)
            y += 1

    def GetEnabledStrings(self):
        return self.GetStrings(self.addcolumns)

    def GetDisabledStrings(self):
        return self.GetStrings(self.removedcolumns)

    def GetStrings(self, columns):
        res = []
        for x in range(columns.GetCount()):
            res.append(columns.GetString(x))
        return res
